@@ -23,21 +23,23 @@
 #include "libgswitchit/gswitchit_plugin_manager.h"
 
 typedef struct _GSwitchItApplet {
-	GSwitchItPluginContainer pluginContainer;
-
-	GSwitchItConfig config;
-	GSwitchItAppletConfig appletConfig;
-	GSwitchItKbdConfig kbdConfig;
-	GSwitchItPluginManager pluginManager;
-
 	GtkWidget *applet;
+	GtkWidget *appletAncestor;
 	GtkWidget *notebook;
 	GtkWidget *ebox;
 	GtkWidget *aboutDialog;
-
-	GSList *groupNames;
 } GSwitchItApplet;
 
+typedef struct _GSwitchItAppletGlobals {
+        GSwitchItPluginContainer pluginContainer;
+        GSwitchItPluginManager pluginManager;
+        GSwitchItConfig config;
+        GSwitchItAppletConfig appletConfig;
+        GSwitchItKbdConfig kbdConfig;
+        GSList *groupNames;
+        GSList *appletInstances;
+} GSwitchItAppletGlobals;
+
 extern void GSwitchItAppletRevalidate (GSwitchItApplet * sia);
 extern void GSwitchItAppletRevalidateGroup (GSwitchItApplet * sia,
 					    int group);
@@ -45,8 +47,7 @@ extern void GSwitchItAppletRevalidateGroup (GSwitchItApplet * sia,
 extern void GSwitchItAppletReinitUi (GSwitchItApplet * sia);
 
 extern GdkFilterReturn GSwitchItAppletFilterXEvt (GdkXEvent * xevent,
-						  GdkEvent * event,
-						  GSwitchItApplet * sia);
+						  GdkEvent * event);
 
 extern gboolean GSwitchItAppletNew (PanelApplet * applet);
 
