@@ -171,8 +171,7 @@ CappletPromotePlugin (GtkWidget * btnUp, GSwitchItPluginsCapplet * gswic)
 						     fullPath);
 		g_free (fullPath);
 		CappletFillActivePluginList (gswic);
-		GSwitchItAppletConfigSave (&gswic->appletConfig,
-					   &gswic->xkbConfig);
+		GSwitchItAppletConfigSaveToGConf (&gswic->appletConfig);
 	}
 }
 
@@ -187,8 +186,7 @@ CappletDemotePlugin (GtkWidget * btnUp, GSwitchItPluginsCapplet * gswic)
 						    fullPath);
 		g_free (fullPath);
 		CappletFillActivePluginList (gswic);
-		GSwitchItAppletConfigSave (&gswic->appletConfig,
-					   &gswic->xkbConfig);
+		GSwitchItAppletConfigSaveToGConf (&gswic->appletConfig);
 	}
 }
 
@@ -204,8 +202,7 @@ CappletDisablePlugin (GtkWidget * btnRemove,
 						     fullPath);
 		g_free (fullPath);
 		CappletFillActivePluginList (gswic);
-		GSwitchItAppletConfigSave (&gswic->appletConfig,
-					   &gswic->xkbConfig);
+		GSwitchItAppletConfigSaveToGConf (&gswic->appletConfig);
 	}
 }
 
@@ -231,7 +228,7 @@ CappletResponse (GtkDialog * dialog, gint response)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GSwitchItHelp (GTK_WIDGET (dialog),
-			       "gswitchitAppletPlugins");
+			       "gswitchit-applet-plugins");
 		return;
 	}
 
@@ -254,7 +251,8 @@ CappletSetup (GSwitchItPluginsCapplet * gswic)
 	GtkTreeSelection *selection;
 	const char *iconFile;
 	glade_gnome_init ();
-	data = glade_xml_new (GLADE_DIR "/gswitchit-plugins.glade", "gswitchit_plugins", NULL);	// default domain!
+	/* default domain! */
+	data = glade_xml_new (GNOME_GLADEDIR "/gswitchit-plugins.glade", "gswitchit_plugins", NULL);	
 	gswic->capplet = capplet =
 	    glade_xml_get_widget (data, "gswitchit_plugins");
 	iconFile = gnome_program_locate_file (NULL,
@@ -320,11 +318,11 @@ main (int argc, char **argv)
 	GError *gconf_error = NULL;
 	GConfClient *confClient;
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (PACKAGE);
+	textdomain (GETTEXT_PACKAGE);
 	memset (&gswic, 0, sizeof (gswic));
-	gnome_program_init ("gswitchit-properties", VERSION,
+	gnome_program_init ("gswitchit", VERSION,
 			    LIBGNOMEUI_MODULE, argc, argv,
 			    GNOME_PROGRAM_STANDARD_PROPERTIES, NULL); 
 	if (!gconf_init (argc, argv, &gconf_error)) {
@@ -334,7 +332,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 	gconf_error = NULL;
-	//GSwitchItInstallGlibLogAppender(  );
+	/*GSwitchItInstallGlibLogAppender(  );*/
 	XklInit (GDK_DISPLAY ());
 	XklConfigInit ();
 	XklConfigLoadRegistry ();
@@ -343,18 +341,16 @@ main (int argc, char **argv)
 	GSwitchItPluginContainerInit (&gswic.pluginContainer, confClient);
 	g_object_unref (confClient);
 
-	GSwitchItXkbConfigInit (&gswic.xkbConfig, confClient);
+	GSwitchItKbdConfigInit (&gswic.kbdConfig, confClient);
 	GSwitchItAppletConfigInit (&gswic.appletConfig, confClient);
 	GSwitchItPluginManagerInit (&gswic.pluginManager);
-	GSwitchItXkbConfigLoad (&gswic.xkbConfig);
-	GSwitchItAppletConfigLoad (&gswic.appletConfig);
-	if (gswic.appletConfig.debugLevel != -1)
-		XklSetDebugLevel (gswic.appletConfig.debugLevel);
+	GSwitchItKbdConfigLoadFromGConf (&gswic.kbdConfig);
+	GSwitchItAppletConfigLoadFromGConf (&gswic.appletConfig);
 	CappletSetup (&gswic);
 	bonobo_main ();
 	GSwitchItPluginManagerTerm (&gswic.pluginManager);
 	GSwitchItAppletConfigTerm (&gswic.appletConfig);
-	GSwitchItXkbConfigTerm (&gswic.xkbConfig);
+	GSwitchItKbdConfigTerm (&gswic.kbdConfig);
 	GSwitchItPluginContainerTerm (&gswic.pluginContainer);
 	XklConfigFreeRegistry ();
 	XklConfigTerm ();
@@ -362,20 +358,14 @@ main (int argc, char **argv)
 	return 0;
 }
 
-// functions just for plugins - otherwise ldd is not happy
+/* functions just for plugins - otherwise ldd is not happy */
 void
 GSwitchItPluginContainerReinitUi (GSwitchItPluginContainer * pc)
 {
 }
 
-void
-GSwitchItPluginLoadLocalizedGroupNames (GSwitchItPluginContainer
-					* pc,
-					const GroupDescriptionsBuffer
-					** outDescr)
+GSList *
+GSwitchItPluginLoadLocalizedGroupNames (GSwitchItPluginContainer * pc)
 {
-	static GroupDescriptionsBuffer namesToFill;
-	GSwitchItAppletConfigLoadGroupDescriptionsUtf8 (&
-							(((GSwitchItPluginsCapplet *) pc)->appletConfig), namesToFill);
-	*outDescr = (const GroupDescriptionsBuffer *) (&namesToFill);
+	return GSwitchItConfigLoadGroupDescriptionsUtf8 (&(((GSwitchItPluginsCapplet *) pc)->config));
 }
