@@ -41,6 +41,23 @@ static gchar* history_auto_complete(GtkWidget *widget, GdkEventKey *event);
 static int history_position = MC_HISTORY_LIST_LENGTH;
 static gchar *browsed_folder = NULL;
 
+static gboolean
+button_press_cb (GtkEntry       *entry,
+		 GdkEventButton *event,
+		 MCData         *mc)
+{
+    const gchar *str;
+
+    panel_applet_request_focus (mc->applet, event->time);
+
+    if (mc->error) { 
+	   mc->error = FALSE; 
+	   str = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	   gtk_entry_set_text (entry, (gchar *) str + 3);
+	}
+    return FALSE;
+}
+
 static gboolean
 command_key_event (GtkEntry   *entry,
 		   GdkEventKey *event,
@@ -51,7 +68,14 @@ command_key_event (GtkEntry   *entry,
     static char current_command[MC_MAX_COMMAND_LENGTH];
     char buffer[MC_MAX_COMMAND_LENGTH];
     gboolean propagate_event = TRUE;
+    const gchar *str;
 
+    if (mc->error) { 
+	   mc->error = FALSE; 
+	   str = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	   gtk_entry_set_text (entry, (gchar *) str + 3);
+	   gtk_editable_set_position (GTK_EDITABLE (entry), strlen (str));
+	}
     if(key == GDK_Tab
        || key == GDK_KP_Tab
        || key == GDK_ISO_Left_Tab)
@@ -120,12 +144,10 @@ command_key_event (GtkEntry   *entry,
 	    strcpy(command, (char *) gtk_entry_get_text(entry));
 	    mc_exec_command(mc, command);
 
-	    append_history_entry(mc, (char *) command, FALSE);
 	    history_position = MC_HISTORY_LIST_LENGTH;		   
 	    free(command);
 
 	    strcpy(current_command, "");
-	    gtk_entry_set_text(entry, (gchar *) "");
 	    propagate_event = FALSE;
 	}
     else if (mc->preferences.auto_complete_history && key >= GDK_space && key <= GDK_asciitilde )
@@ -276,7 +298,7 @@ mc_show_history (GtkWidget *widget,
 			    gtk_widget_get_screen (GTK_WIDGET (mc->applet)));
      gtk_window_set_policy(GTK_WINDOW(window), 0, 0, 1);
      /* cb */
-     gtk_signal_connect_after(GTK_OBJECT(window),
+     g_signal_connect_after(GTK_OBJECT(window),
 			      "button_press_event",
 			      GTK_SIGNAL_FUNC(history_popup_clicked_cb),
 			      NULL);
@@ -299,7 +321,7 @@ mc_show_history (GtkWidget *widget,
      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
 				    GTK_POLICY_AUTOMATIC,
 				    GTK_POLICY_AUTOMATIC);
-     gtk_signal_connect(GTK_OBJECT(scrolled_window),
+     g_signal_connect(GTK_OBJECT(scrolled_window),
 			"button_press_event",
 			GTK_SIGNAL_FUNC(history_popup_clicked_inside_cb),
 			NULL);
@@ -473,8 +495,17 @@ mc_create_command_entry (MCData *mc)
     g_signal_connect (mc->entry, "key_press_event",
 		      G_CALLBACK (command_key_event), mc);
    
+    g_signal_connect (mc->entry, "button_press_event",
+		      G_CALLBACK (button_press_cb), mc);
+
     if (!mc->preferences.show_default_theme)
-        mc_command_update_entry_color (mc); 
+    {
+	    gtk_widget_set_name (mc->entry, "minicommander-applet-entry");
+	    mc_command_update_entry_color (mc); 
+    }
+    else
+	    gtk_widget_set_name (mc->entry,
+			    "minicommander-applet-entry-default");
 
     mc_command_update_entry_size (mc);
 
@@ -488,11 +519,26 @@ mc_command_update_entry_color (MCData *mc)
 {
     GdkColor fg;
     GdkColor bg;
+    char *rc_string;
 
     fg.red   = mc->preferences.cmd_line_color_fg_r;
     fg.green = mc->preferences.cmd_line_color_fg_g;
     fg.blue  = mc->preferences.cmd_line_color_fg_b;
 
+    /* FIXME: wish we had an API for this, see bug #79585 */
+    rc_string = g_strdup_printf (
+		    "\n"
+		    " style \"minicommander-applet-entry-style\"\n"
+		    " {\n"
+		    "  GtkWidget::cursor-color=\"#%04x%04x%04x\"\n"
+		    " }\n"
+		    " widget \"*.minicommander-applet-entry\" "
+		    "style \"minicommander-applet-entry-style\"\n"
+		    "\n",
+		    fg.red, fg.green, fg.blue);
+    gtk_rc_parse_string (rc_string);
+    g_free (rc_string);
+
     gtk_widget_modify_text (mc->entry, GTK_STATE_NORMAL, &fg);
     gtk_widget_modify_text (mc->entry, GTK_STATE_PRELIGHT, &fg);
    
@@ -510,14 +556,12 @@ mc_command_update_entry_size (MCData *mc)
     int size_x = -1;
     
     size_x = mc->preferences.normal_size_x - 17;
-
-    if (mc->preferences.show_handle)
-	size_x -= 10;
-
-    if (mc->preferences.show_frame)
-	size_x -= 10;
-    
-    gtk_widget_set_size_request (GTK_WIDGET (mc->entry), size_x, mc->preferences.normal_size_y+4); 
+    if ((mc->orient == PANEL_APPLET_ORIENT_LEFT) || (mc->orient == PANEL_APPLET_ORIENT_RIGHT)) {
+      size_x = MIN(size_x, mc->preferences.panel_size_x - 17);
+      gtk_widget_set_size_request (GTK_WIDGET (mc->entry), size_x, -1);
+    } else {
+      gtk_widget_set_size_request (GTK_WIDGET (mc->entry), size_x, mc->preferences.normal_size_y+2);
+    }
 }
 
 
